CREATE TABLE kiwi_profile (
profile_id integer NOT NULL PRIMARY KEY,
profile_name character varying(250),
profile_project character(5),
profile_schedule character(5),
profile_approval character(5),
profile_file character(5),
profile_forum character(5),
profile_mockup character(5),
profile_support character(5),
profile_user character(5),
profile_system character(5),
profile_admin character(5),
profile_event character(5)
);

INSERT INTO kiwi_profile VALUES('500','Administrator','RECDA','RECDA','RECDA','RECDA','RECD','RECDA','RECDA','RECDA','R','R','RECDA');
INSERT INTO kiwi_profile VALUES('400','Manager','RECD','RECDA','RECDA','RECDA','RECD','RECDA','RECDA','','','R','RECD');
INSERT INTO kiwi_profile VALUES('300','Employee','R','R','REC','REC','REC','RECD','REC','','','R','R');
INSERT INTO kiwi_profile VALUES('200','Contractor','R','R','REC','REC','REC','R','RC','','','R','');
INSERT INTO kiwi_profile VALUES('100','Client','R','R','REC','REC','','R','RC','','','R','');

CREATE TABLE kiwi_organization (
organization_id integer NOT NULL PRIMARY KEY,
organization_name character varying(250),
organization_pn character varying(250),
organization_fn character varying(250),
organization_url character varying(250),
organization_address text,
organization_comments text,
organization_created bigint,
organization_modified bigint
);

CREATE TABLE kiwi_user (
user_id integer NOT NULL PRIMARY KEY,
profile_id integer NOT NULL,
organization_id integer,
user_name character varying(250),
user_title character varying(250),
user_email character varying(250) CONSTRAINT email UNIQUE,
user_wp character varying(250),
user_hp character varying(250),
user_mp character varying(250),
user_fax character varying(250),
user_address text,
user_comments text,
user_username character varying(150) NOT NULL CONSTRAINT username UNIQUE,
user_password character varying(150) NOT NULL,
user_created bigint,
user_modified bigint,
user_notify character varying(50),
user_attempt integer,
user_blocked bigint,
user_key char(40),
user_active char(1),
user_timezone numeric(10,2)
);

CREATE TABLE kiwi_project (
project_id integer NOT NULL PRIMARY KEY,
organization_id integer,
project_status character varying(100),
project_name character varying(250),
project_priority character varying(250),
project_description text,
project_development_url character varying(250),
project_finalsite_url character varying(250),
project_created bigint,
project_modified bigint,
project_poster_id integer,
FOREIGN KEY (project_poster_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_file (
file_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
user_id integer NOT NULL,
file_path character varying(250),
file_type character varying(250),
file_parent integer,
file_status character varying(250),
file_comments text,
file_version character varying(250),
file_created bigint,
file_modified bigint,
file_published character varying(10),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_schedule (
schedule_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
schedule_group_id integer,
schedule_name character varying(150),
schedule_comments text,
schedule_status integer,
schedule_priority character varying(150),
schedule_start bigint,
schedule_duration integer,
schedule_delay integer,
schedule_budget_cost numeric(50,2),
schedule_budget_hour numeric(50,2),
schedule_created bigint,
schedule_modified bigint,
schedule_end bigint,
schedule_poster_id integer,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_poster_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_schedule_relation (
schedule_relation_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
schedule_relation_parent integer NOT NULL,
schedule_relation_child integer NOT NULL,
schedule_relation_type character varying(150),
schedule_relation_lead integer,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_relation_parent) REFERENCES kiwi_schedule(schedule_id),
FOREIGN KEY (schedule_relation_child) REFERENCES kiwi_schedule(schedule_id)
);

CREATE TABLE kiwi_schedule_group (
schedule_group_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
schedule_group_name character varying(150),
schedule_group_created bigint,
schedule_group_modified bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id)
);

CREATE TABLE kiwi_user_schedule (
user_schedule_id integer NOT NULL PRIMARY KEY,
user_id integer NOT NULL,
project_id integer NOT NULL,
schedule_id integer NOT NULL,
user_schedule_created bigint,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id)
);

CREATE TABLE kiwi_approval (
approval_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
approval_requested_by integer NOT NULL,
approval_requested_from integer NOT NULL,
approval_name character varying(250),
approval_comments text,
approval_created bigint,
approval_modified bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (approval_requested_by) REFERENCES kiwi_user(user_id),
FOREIGN KEY (approval_requested_from) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_approval_file (
approval_file_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
approval_id integer NOT NULL,
file_id integer NOT NULL,
approval_file_status character varying(250),
approval_file_created bigint,
approval_file_modified bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (approval_id) REFERENCES kiwi_approval(approval_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id)
);

CREATE TABLE kiwi_approval_log (
approval_log_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
user_id integer,
approval_id integer NOT NULL,
approval_log_comments text,
approval_log_created bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (approval_id) REFERENCES kiwi_approval(approval_id)
);

CREATE TABLE kiwi_expense (
expense_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
schedule_id integer NOT NULL,
expense_name character varying(250),
expense_amount numeric(50,2),
expense_comments text,
expense_created bigint,
expense_modified bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id)
);

CREATE TABLE kiwi_forum_topic (
forum_topic_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
forum_topic_poster_id integer NOT NULL,
forum_topic_title text,
forum_topic_views integer,
forum_topic_messages integer,
forum_topic_created bigint,
forum_topic_modified bigint,
forum_topic_locked char(1),
forum_topic_sticky char(1),
forum_topic_deleted char(1),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (forum_topic_poster_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_forum_message (
forum_message_id integer NOT NULL PRIMARY KEY,
forum_topic_id integer NOT NULL,
user_id integer NOT NULL,
forum_message_comments text,
forum_message_created bigint,
forum_message_modified bigint,
FOREIGN KEY (forum_topic_id) REFERENCES kiwi_forum_topic(forum_topic_id) ON DELETE CASCADE,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_forum_attachment (
forum_attachment_id integer NOT NULL PRIMARY KEY,
forum_message_id integer NOT NULL,
project_id integer NOT NULL,
file_id integer NOT NULL,
FOREIGN KEY (forum_message_id) REFERENCES kiwi_forum_message(forum_message_id) ON DELETE CASCADE,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id) ON DELETE CASCADE
);

CREATE TABLE kiwi_log (
log_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
schedule_id integer NOT NULL,
user_id integer NOT NULL,
log_rate numeric(50,2),
log_hours numeric(50,2),
log_comments text,
log_created bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_mockup (
mockup_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
user_id integer NOT NULL,
file_id integer,
mockup_parent integer,
mockup_name character varying(250),
mockup_comments text,
mockup_created bigint,
mockup_modified bigint,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_project_user (
project_user_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
user_id integer NOT NULL,
project_user_created bigint,
project_user_status character varying(150),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_review (
review_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
user_id integer NOT NULL,
file_id integer NOT NULL,
review_comments text,
review_created integer,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id)
);

CREATE TABLE kiwi_support_topic (
support_topic_id integer NOT NULL PRIMARY KEY,
project_id integer NOT NULL,
support_topic_poster_id integer NOT NULL,
support_topic_operator_id integer,
support_topic_title text,
support_topic_views integer,
support_topic_messages integer,
support_topic_created bigint,
support_topic_modified bigint,
support_topic_priority character varying(150),
support_topic_status character varying(150),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (support_topic_poster_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (support_topic_operator_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_support_message (
support_message_id integer NOT NULL PRIMARY KEY,
support_topic_id integer NOT NULL,
user_id integer NOT NULL,
support_message_comments text,
support_message_created bigint,
support_message_modified bigint,
FOREIGN KEY (support_topic_id) REFERENCES kiwi_support_topic(support_topic_id) ON DELETE CASCADE,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_user_log (
user_log_id integer NOT NULL PRIMARY KEY,
user_username character varying(150),
user_password character varying(150),
user_log_ip character varying(150),
user_log_session character varying(150),
user_log_status character varying(150),
user_log_date bigint,
user_log_connected character varying(150)
);

CREATE TABLE kiwi_holiday (
holiday_id integer NOT NULL PRIMARY KEY,
holiday_name character varying(250),
holiday_date bigint,
holiday_created bigint
);

CREATE TABLE kiwi_history (
history_id bigint NOT NULL PRIMARY KEY,
user_id integer NOT NULL,
history_location text,
history_url text,
history_created bigint,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_note (
note_id bigint NOT NULL PRIMARY KEY,
user_id integer NOT NULL,
note_comments text,
note_type character varying(50),
note_created bigint,
note_modified bigint,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_event (
event_id integer NOT NULL PRIMARY KEY,
user_id integer NOT NULL,
event_title text,
event_location text,
event_comments text,
event_start bigint,
event_end bigint,
event_timezone numeric(10,2),
event_type character varying(25),
event_created bigint,
event_modified bigint,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
);

CREATE TABLE kiwi_event_recursion (
event_recursion_id integer NOT NULL PRIMARY KEY,
event_id integer NOT NULL,
event_recursion_frequency character varying(50),
event_recursion_interval integer,
event_recursion_bymonth integer,
event_recursion_bymonthday integer,
event_recursion_byday character varying(50),
event_recursion_byyearday integer,
event_recursion_byweekno integer,
event_recursion_bysetpos integer,
event_recursion_until bigint,
FOREIGN KEY (event_id) REFERENCES kiwi_event(event_id)
);

CREATE TABLE kiwi_event_exception (
event_exception_id integer NOT NULL PRIMARY KEY,
event_id integer NOT NULL,
event_parent integer NOT NULL,
event_exception_date bigint,
FOREIGN KEY (event_id) REFERENCES kiwi_event(event_id),
FOREIGN KEY (event_parent) REFERENCES kiwi_event(event_id)
);

CREATE TABLE kiwi_session (
session_id character varying(250) NOT NULL PRIMARY KEY,
session_data text,
session_expires bigint
);

CREATE TABLE kiwi_notification (
notification_id integer NOT NULL PRIMARY KEY,
notification_module character varying(50),
notification_action character varying(50),
notification_status character varying(50)
);

INSERT INTO kiwi_notification VALUES(1,'schedule','create','Y');
INSERT INTO kiwi_notification VALUES(2,'schedule','edit','N');
INSERT INTO kiwi_notification VALUES(3,'schedule','status','N');
INSERT INTO kiwi_notification VALUES(4,'approval','create','Y');
INSERT INTO kiwi_notification VALUES(5,'approval','status','Y');
INSERT INTO kiwi_notification VALUES(6,'approval','comment','Y');
INSERT INTO kiwi_notification VALUES(7,'file','upload','Y');
INSERT INTO kiwi_notification VALUES(8,'file','update','Y');
INSERT INTO kiwi_notification VALUES(9,'file','review','Y');
INSERT INTO kiwi_notification VALUES(10,'forum','post','Y');
INSERT INTO kiwi_notification VALUES(11,'forum','reply','Y');
INSERT INTO kiwi_notification VALUES(12,'mockup','create','N');
INSERT INTO kiwi_notification VALUES(13,'mockup','edit','N');
INSERT INTO kiwi_notification VALUES(14,'support','post','Y');
INSERT INTO kiwi_notification VALUES(15,'support','reply','Y');

CREATE SEQUENCE event_id_seq;
CREATE SEQUENCE event_recursion_id_seq;
CREATE SEQUENCE event_exception_id_seq;

CREATE SEQUENCE note_id_seq;
CREATE SEQUENCE organization_id_seq;
CREATE SEQUENCE user_id_seq;
CREATE SEQUENCE project_id_seq;
CREATE SEQUENCE file_id_seq;
CREATE SEQUENCE schedule_id_seq;
CREATE SEQUENCE schedule_relation_id_seq;
CREATE SEQUENCE schedule_group_id_seq;
CREATE SEQUENCE approval_id_seq;
CREATE SEQUENCE approval_file_id_seq;
CREATE SEQUENCE approval_log_id_seq;
CREATE SEQUENCE expense_id_seq;
CREATE SEQUENCE forum_attachment_id_seq;
CREATE SEQUENCE log_id_seq;
CREATE SEQUENCE mockup_id_seq;
CREATE SEQUENCE project_user_id_seq;
CREATE SEQUENCE user_schedule_id_seq;
CREATE SEQUENCE review_id_seq;
CREATE SEQUENCE user_log_id_seq;
CREATE SEQUENCE holiday_id_seq;
CREATE SEQUENCE history_id_seq;
CREATE SEQUENCE profile_id_seq START 1000;

CREATE SEQUENCE forum_topic_id_seq START 100000;
CREATE SEQUENCE forum_message_id_seq START 100000;

CREATE SEQUENCE support_topic_id_seq START 100000;
CREATE SEQUENCE support_message_id_seq START 100000;

INSERT INTO kiwi_user(user_id,profile_id,user_name,user_username,user_password,user_active,user_timezone) VALUES ('398571525','500','Admin','admin','6441a0e520f56a5fc6f80f33b8e1f3ad6a0b75d6','Y','0');
